# delete-empty [![NPM version](https://img.shields.io/npm/v/delete-empty.svg?style=flat)](https://www.npmjs.com/package/delete-empty) [![NPM downloads](https://img.shields.io/npm/dm/delete-empty.svg?style=flat)](https://npmjs.org/package/delete-empty) [![Build Status](https://img.shields.io/travis/jonschlinkert/delete-empty.svg?style=flat)](https://travis-ci.org/jonschlinkert/delete-empty)

> Recursively delete all empty folders in a directory and child directories.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install delete-empty --save
```

## Usage

```js
var deleteEmpty = require('delete-empty');
```

## API

Given the following directory structure, the **highlighted directories** would be deleted.

```diff
foo/
└─┬ a/
-  ├── aa/
  ├── bb/
  │ └─┬ bbb/
  │   ├── one.txt
  │   └── two.txt
-  ├── cc/
-  ├ b/
-  └ c/
```

**async**

```js
deleteEmpty('foo/', function(err, deleted) {
  console.log(deleted);
  //=> ['foo/aa/', 'foo/a/cc/', 'foo/b/', 'foo/c/']
});
```

**sync**

```js
deleteEmpty.sync('foo/');
```

As with the async method, an array of deleted directories is returned, in case you want to log them out or provide some kind of feedback to the user.

```js
var deleted = deleteEmpty.sync('foo/');
console.log(deleted);
//=> ['foo/aa/', 'foo/a/cc/', 'foo/b/', 'foo/c/']
```

## Related projects

You might also be interested in these projects:

* [copy](https://www.npmjs.com/package/copy): Copy files or directories using globs. | [homepage](https://github.com/jonschlinkert/copy)
* [delete](https://www.npmjs.com/package/delete): Delete files and folders and any intermediate directories if they exist (sync and async). | [homepage](https://github.com/jonschlinkert/delete)
* [fs-utils](https://www.npmjs.com/package/fs-utils): fs extras and utilities to extend the node.js file system module. Used in Assemble and… [more](https://www.npmjs.com/package/fs-utils) | [homepage](https://github.com/assemble/fs-utils)
* [matched](https://www.npmjs.com/package/matched): Adds array support to node-glob, sync and async. Also supports tilde expansion (user home) and… [more](https://www.npmjs.com/package/matched) | [homepage](https://github.com/jonschlinkert/matched)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/delete-empty/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/delete-empty/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on March 24, 2016._